/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: AgentHeartbeat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: AgentHeartbeat.h,v 1.4 2008/12/15 15:07:14 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_AGENTHEARTBEAT_H_
#define GLITE_DATA_TRANSFER_AGENTS_AGENTHEARTBEAT_H_

#include <glite/data/transfer/agent/model/Agent.h>
#include <glite/data/agents/dao/DAOContext.h>
#include <glite/data/config/service/Logger.hxx>

#include <boost/utility.hpp>
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {

/**
 * The purpose of that Action is to set the lastActive timestamp for an agent
 */
template<class F>
class AgentHeartbeat : boost::noncopyable{

public:
    /**
     * Constructor
     */
    AgentHeartbeat();

    /**
     * Destructor
     */
    ~AgentHeartbeat();

    /**
     * Execute The Action
     */
    void run(class agents::dao::DAOContext& ctx, const std::string& name) /*throw (DAOException, LogicError)*/;
 
private:
    
    /**
     * The Logger
     */
    glite::config::Logger m_logger;
};

} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#include "glite/data/transfer/agent/AgentHeartbeat.inl"

#endif //GLITE_DATA_TRANSFER_AGENTS_AGENTHEARTBEAT_H_
