/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: AgentHeartbeat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: AgentHeartbeat.inl,v 1.6 2008/11/13 10:43:55 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#include <glite/data/transfer/agent/dao/AgentDAO.h>

#include <boost/scoped_ptr.hpp>
#include <unistd.h>

/*
 * Constants
 */
namespace {
const char * const AGENT_HEARTBEAT_NAME  = "transfer-agent-heartbeat";
}

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
    
/*
 * AgentHeartbeat
 *
 * Constructor
 */
template <class F>
AgentHeartbeat<F>::AgentHeartbeat(): 
    m_logger(AGENT_HEARTBEAT_NAME){
}
                                                                                                                          
/*
 * ~AgentHeartbeat
 *
 * Destructor
 */
template <class F>
AgentHeartbeat<F>::~AgentHeartbeat(){
}

/*
 * run
 *
 * Update the LastActive timestamp
 */
template <class F>
void AgentHeartbeat<F>::run(agents::dao::DAOContext& ctx, const std::string& name) /*throw(DAOException)*/{
    
    // Get current Time
    time_t current;
    time(&current);

    // Create DAO Context
    try{
        // Create a AgentDAO instance
        boost::scoped_ptr<dao::AgentDAO> agentDao(
            F::instance().createAgentDAO(name,ctx));
    
        // Try to get the Agent Instance
        boost::scoped_ptr<model::Agent> agent(agentDao->get());
        
        // Update Fields
        agent->state = model::Agent::S_STARTED;
        agent->lastActive = current;
        
        // Start Transaction
        ctx.start();
        
        // Insert the Instance
        agentDao->update(*agent);

        // Commit Transaction
        ctx.commit();

        // Also log the heartbeat (eventually a sensor could be easily created)
        m_log_info("HEARTBEAT: Agent <" << name << "> is alive");
    } catch(const agents::dao::DAOException& exc){
        m_log_error("Can't set Agent lastActive. Reason is " << exc.what());
        ctx.rollback();
        throw;
    } catch(const agents::LogicError& exc){
        m_log_error("Can't set Agent lastActive (LogicError). Reason is " << exc.what());
        ctx.rollback();
        throw;
    }
}

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite
