/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: CatalogRetryStrategy Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CatalogRetryStrategy.h,v 1.2 2006/08/14 08:37:41 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_CATALOGRETRYSTRATEGY_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_CATALOGRETRYSTRATEGY_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/model/Error.h"

#include <vector>
#include <boost/shared_ptr.hpp>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {
namespace vo      {

/**
 * The purpose of that Strategy is to define if the catalog interaction for 
 * a job has to be retried, failed or has to stay in 
 * WaitingCatalogResolution/Registration
 */
class CatalogRetryStrategy : boost::noncopyable {
public:

    typedef std::vector<boost::shared_ptr<const model::File> > FileArray;

    /**
     * CatalogRetryResult Type
     */
    typedef enum{
        UNDEF   = 0,
        WAIT       ,
        RETRY      ,
        FAIL
    } CatalogRetryResult;

    /**
     * Destructor
     */
    virtual ~CatalogRetryStrategy(){}

    /**
     * Execute The Action
     */
    virtual CatalogRetryResult apply(const model::Job& job,const FileArray& files) /*throw (LogicError,ExecuteException)*/ = 0;

protected:
    /**
     * Constructor
     */
    CatalogRetryStrategy(){}
};

} // End namespace vo
} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_CATALOGRETRYSTRATEGY_H_
