/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: JobDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobDAO.h,v 1.11 2007/07/04 13:08:13 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/agents/dao/DAOException.h"
#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Job class
 * @interface
 */
class JobDAO : boost::noncopyable{
public:

    /**
     * Destructor
     */
    virtual ~JobDAO(){}
        
    /**
     * Return the Job with the given id
     */
    virtual model::Job * get(const std::string& id) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Return the Job with the given id searching all jobs (also where the  
     * "job_finished" flag is set).
     * This function should be used only for tests.
     */
    virtual model::Job * getFullSearch(const std::string& id) /*throw (DAOLogicError,DAOException)*/ = 0;    
        
    /**
     * Update a Job object
     */
    virtual void update(const model::Job& obj) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Update the state of all the transfer jobs in the given array
     * Note: Probably this shoudn't be a DAO method, but I assume that it could 
     * be implemented using features like Triggers or Stored Procedures 
     * available on some Data Sources
     */
    virtual void updateStates(const agents::dao::StringArray& ids) /*throw (DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::Job lnkJob; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
