/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: TSSCredFactory
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CredChannelFactory.h,v 1.2 2006/08/14 08:37:46 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CREDCHANNELFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CREDCHANNELFACTORY_H_

#include "glite/data/transfer/agent/dao/TSSCredFactory.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {
    
/**
 * The purpose of this class is to create a CredDao with the 
 * correct Factory(vo,channel,cred)
 */
class CredChannelFactory: public CredFactory {
public:
    /**
     * Constructor
     */
    explicit CredChannelFactory(const std::string& ch_name):m_channelName(ch_name){};

    /**
     * create a CredDao with the correct Factory
     */
    virtual CredDAO * create(agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/{
        // Create a CredDAO from the VO DAOFactory
        return dao::channel::DAOFactory::instance().createCredDAO(m_channelName,ctx);
    }

    /**
     * Destructor
     */
    virtual ~CredChannelFactory(){};
private:
    /**
     * Constructor. Not Implemented
     */
    CredChannelFactory();
private:
    /**
     * The Channel Name
     */
    std::string m_channelName;
};
    
} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CREDCHANNELFACTORY_H_
