/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: TransferDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferDAO.h,v 1.11 2006/08/14 08:37:47 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_TRANSFERDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_TRANSFERDAO_H_

#include "glite/data/transfer/agent/model/Transfer.h"
#include "glite/data/transfer/agent/dao/TransferDAO.h"

#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {

/**
 * Data Access Object For the model::Transfer class, filtered with a Channel View
 * @interface
 */
class TransferDAO : public glite::data::transfer::agent::dao::TransferDAO{
public:
    typedef  agents::dao::StringPair      StringPair;
    typedef  agents::dao::StringPairArray StringPairArray;
    
    /**
     * Destructor
     */
    virtual ~TransferDAO(){}
        
    /**
     * Update a Transfer instance
     */
    virtual void update(const model::Transfer& obj) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Create a Transfer instance
     */
    virtual void create(const model::Transfer& obj) /*throw (DAOLogicError,DAOException)*/ = 0;
        
    /**
     * Count the active (Received & Processing) Transfer instances on the channel
     */
    virtual unsigned long countActiveTransfers() /*throw (DAOLogicError,DAOException)*/ = 0;
        
    /**
     * Count the active (Received & Processing) Transfer instances the have been
     * submitted by a VO
     */
    virtual unsigned long countActiveTransfers(const std::string& vo_name) /*throw (DAOLogicError,DAOException)*/ = 0;
        
    /**
     * Return the list of active (Received and Processing) Transfers for 
     * the given channel
     * FileIds are retourned grouped by RequestId and ordered by transfer_id.
     */
    virtual void getActiveTransfers(StringPairArray& ids) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Return the list of the active (Received and Processing) Transfers which 
     * Job state is Canceling and File State is Active
     */
    //virtual void getTransfersToCancel(FilesPerRequestList& ids, bool lock = false, unsigned int limit = 0, unsigned int offset = 0) /*throw (DAOLogicError,DAOException)*/ = 0;
};

} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_TRANSFERDAO_H_
