/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: Cred DAOFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: DAOFactory.h,v 1.2 2006/08/14 08:37:47 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_DAOFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_DAOFACTORY_H_

#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/transfer/agent/dao/cred/CredDAO.h"
#include "glite/data/transfer/agent/dao/cred/AgentDAO.h"
#include "glite/data/transfer/agent/dao/cred/JobDAO.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace cred    {

/**
 * Base Class For creating the DataAccessObject Cred instances
 * @interface
 */
class DAOFactory {
public:
    
    /**
     * Validate The DB Schema
     * @param ctx [IN] The DAO Context to use
      */
    virtual void checkSchema(agents::dao::DAOContext& ctx) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model::Cred instances
     * @param ctx [IN] The DAO Context to use
     */
    virtual CredDAO * createCredDAO(agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:Agent instances
     * @param name [IN] The Agent name
     * @param ctx [IN] The DAO Context to use
     */
    virtual AgentDAO * createAgentDAO(const std::string& name,agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model::Job instances
     * @param ctx [IN] The DAO Context to use
     */
    virtual JobDAO * createJobDAO(agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Return the configured DAOFactory Instance. Please note that 
     * this method doesn't allocate the instance (Isn not a singleton)
     * @return the configured DAOFactory 
     * @throws DAOLogicError in case of no DAOFactory is configured
     */
    static DAOFactory& instance() /*throw (DAOLogicError)*/;

protected:

    /**
     * Constructor
     */ 
    DAOFactory();

    /**
     * Destructor
     */ 
    virtual ~DAOFactory();

private:

    /**
     * The registered Instance
     */
    static DAOFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# CredDAO lnkCredDAO; */
};

} // End namespace cred
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_DAOFACTORY_H_
