/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: FileDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileDAO.h,v 1.9 2006/08/14 08:37:48 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_

#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/dao/FileDAO.h"
#include "glite/data/transfer/agent/dao/StringArrayTable.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {

/**
 * Data Access Object For the model::File class, filtered with a VO View
 * @interface
 */
class FileDAO : public glite::data::transfer::agent::dao::FileDAO{
public:
    typedef  StringArrayTable FilesPerJobList;
    
    /**
     * Destructor
     */
    virtual ~FileDAO(){}
        
    /**
     * Return the list of identifiers of the file which state is WAITING and 
     * the related job state is ACTIVE
     * @param fileIds [OUT] The array that will hold the File Ids
     * @param limit   [IN]  The upper row bound of the query
     */
    virtual void getWaitingFiles(agents::dao::StringArray& fileIds, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Return the list of the job-files identifiers for the files which state 
     * is WAITING_CATALOG_RESOLUTION or WAITING_CATALOG_REGISTRATION 
     * @param ids   [OUT] The array that will hold the Ids
     * @param limit [IN]  The upper row bound of the query
     */
    virtual void getCatalogWaitingFiles(FilesPerJobList& ids, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Return the list of identifiers of the file which state is SUBMITTED,
     * PENDING, WAITING or HOLD and the related job state is CANCELING.
     * @param fileIds [OUT] The array that will hold the File Ids
     * @param lock    [IN]  Lock the concerned rows
     * @param limit   [IN]  The upper row bound of the query
     * @param offset  [IN]  The lower row bound of the query
     */
    //virtual void getFilesToCancel(agents::dao::StringArray& fileIds, bool lock = false, unsigned int limit = 0, unsigned int offset = 0) /*throw (DAOException)*/ = 0;
};

} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_
