/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: Cred Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Cred.h,v 1.2 2006/08/14 08:37:49 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_

#include "glite/data/transfer/agent/model/Property.h"
#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {

/**
 * Cred Class
 * @stereotype ValueObject
 */
struct Cred {

    /**
     * Default Constructor
     */
    Cred():expirationTime(-1){}

    /**
     * Constructor
     */
    Cred(const std::string& i,              // cred_id
         const std::string& dn,             // user_dn
         const std::string& c  = "",        // certificate
               time_t       t  = (time_t)-1,// expiration_time
         const std::string& va = ""):       // voms_attribute
            id(i),userDn(dn),certificate(c),expirationTime(t),
            vomsAttributes(va){}
    /**
     * Id Property
     */
    Property<std::string> const id;

    /**
     * User DN Property
     */
    Property<std::string> const userDn;

    /**
     * User Proxy Property
     */
    Property<std::string> certificate;

    /**
     * Proxy Expiration Time Property
     */
    Property<time_t> expirationTime;

    /**
     * VOMS Attributes Property
     */
    Property<std::string> const vomsAttributes;

public:
    /**
     * Reset All R/W Properties
     */
    void reset(){
        certificate.reset();
        expirationTime.reset();
    }        
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_
