/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: NameGeneration Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: NameGeneration.h,v 1.3 2006/08/14 08:37:50 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_
#define GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace namegen {

/**
 * NameGeneration Interface.
 * Define the interface for generation new file SURL starting from the logical 
 * name
 */
class NameGeneration{
public:
    /**
     * Destructor
     */
    virtual ~NameGeneration(){}
        
    /**
     * Generate a destination Name SURL starting from the logical name and the 
     * Se path
     * @param logical [IN] The input Logical Name. It can be either LFN or GUID
     * @param endpoint [IN] The Storage Element endpoint
     * @param se_path [IN] The path on the Storage Element
     * @param storage_class [IN] The storage class for the given file
     * @trhow LogicError, NameGenerationException in case of errors        
     * @return the generated name
     */
    virtual std::string generate(const std::string& logical,const std::string& endpoint, const std::string& se_path, const std::string& storage_class) /*throw (LogicError, NameGenerationException)*/ = 0;

protected:
    /**
     * Constructor
     */
    NameGeneration(){}
};

} // End namespace namegen
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_
