/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: NameGenerationFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: NameGenerationFactory.h,v 1.2 2006/08/14 08:37:50 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_

#include "glite/data/transfer/agent/namegen/NameGeneration.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace namegen {

/**
 * NameGenerationFactory interface
 * @interface
 */
class NameGenerationFactory {
public:

    /**
     * Create a NameGeneration instance
     * @return a new instance of a NameGeneration
     */
    virtual NameGeneration * create() /*throw ()*/; 

    /**
     * Return the configured NameGenerationFactory Instance. Please note that 
     * this method doesn't allocate the instance (it's not a singleton)
     * @return the configued NameGenerationFactory 
     * @throws LogicError in case of no NameGenerationFactory is
     * configured
     */
    static NameGenerationFactory& instance() /*throw (LogicError)*/; 
   
protected:

    /**
     * Constructor
     */ 
    NameGenerationFactory();

    /**
     * Destructor
     */ 
    virtual ~NameGenerationFactory();

private:

    /**
     * The registered Instance
     */
    static NameGenerationFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# NameGeneration lnkNameGeneration; */
};

} // End namespace namegen
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_
