<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="text" indent="no"/>
<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz-</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ_</xsl:variable>
<!-- Input Parameters -->
<xsl:param name="Prefix" select="''"/>
<xsl:param name="MappingFile" select="'fta-alias-mapping.xml'"/>
<xsl:param name="Param" select="''"/>
<xsl:param name="PrintUsage" select="''"/>
<!-- Mapping document -->
<xsl:variable name="mapping" select="document($MappingFile)"/>
<xsl:variable name="param" select="translate($Param,$ucletters,$lcletters)"/>

<!-- Print Usage-->
<xsl:template name="Usage">
#
# When running the XSLT, you can provide the following parameters:
#  - PrintUsage ${ANY_STRING}: Print this error message
#  - Param ${STRING}: The String to query for in the Parameter name and description
#  - MappingFile ${ALIAS_MAPPING_FILE}: use a file that provides a mapping 
#    between the FTA component name and an user friendly alias. 
#    This file should be in the format:
# <![CDATA[
#     <mapping>
#       <component name="${component_name}">${alias_value}</component>
#       <component name="${component_name}">${alias_value}</component>
#       <!-- ... -->
#     </mapping>
#    ]]>
#    Please note that the location of the mapping file is relative to the location of the XSLT file
#    The Default for this parameter is 'fta-alias-mapping.xml'
#
</xsl:template>

<!-- Get Prefix-->
<xsl:template name="GetPrefix">
 <xsl:param name="node"/>
 <xsl:variable name="alias_val">
  <xsl:choose>
   <xsl:when test="$node/@alias"><xsl:value-of select="$node/@alias"/></xsl:when>
   <xsl:otherwise><xsl:value-of select="$mapping/mapping/component[@name=$node/@name]"/></xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:if test="string($Prefix)"><xsl:value-of select="translate($Prefix,$lcletters,$ucletters)"/>_</xsl:if>
 <xsl:if test="string($alias_val)"> <xsl:value-of select="translate($alias_val,$lcletters,$ucletters)"/>_</xsl:if>
</xsl:template>


<!-- Output param -->
<xsl:template name="OutputParam">
 <xsl:param name="component_name"/>
 <xsl:param name="param_prefix"/>
 <xsl:param name="param_node"/>
 <xsl:text>
 
--------------------------------------------------------------------------------
Parameter: </xsl:text>
<xsl:if test="$param_prefix">
   <xsl:value-of select="$param_prefix"/>
</xsl:if>
<xsl:value-of select="translate($param_node/@name,$lcletters,$ucletters)"/>

(<xsl:value-of select="$component_name"/>.<xsl:value-of select="$param_node/@name"/>)
--------------------------------------------------------------------------------
<xsl:text>
Type: </xsl:text>
<xsl:choose>
<xsl:when test="$param_node/@type"><xsl:value-of select="$param_node/@type"/></xsl:when>
<xsl:otherwise>string</xsl:otherwise>
</xsl:choose>
<xsl:text>

Level: </xsl:text>
<xsl:choose>
<xsl:when test="$param_node/@level"><xsl:value-of select="$param_node/@level"/></xsl:when>
<xsl:otherwise>user</xsl:otherwise>
</xsl:choose>
<xsl:text>

Description:

</xsl:text>
<xsl:value-of select="$param_node/description"/>
<xsl:text>

Default Value: </xsl:text><xsl:value-of select="$param_node/value"/>
</xsl:template>

<!-- Process param -->
<xsl:template name="ProcessParam">
 <xsl:param name="component_name"/>
 <xsl:param name="param_prefix"/>
 <xsl:if test="string(@mandatory) != 'fixed'">
 <xsl:variable name="name_lc">
  <xsl:value-of select="translate(@name,$ucletters,$lcletters)"/>
 </xsl:variable>
 <xsl:variable name="description_lc">
  <xsl:value-of select="translate(./description,$ucletters,$lcletters)"/>
 </xsl:variable>
 <!-- Check if the Parameter contains the requested string in the name-->
 <xsl:choose>
  <xsl:when test="contains($description_lc,$param)">
   <xsl:call-template name="OutputParam">
     <xsl:with-param name="component_name" select="$component_name"/>
     <xsl:with-param name="param_prefix" select="$param_prefix"/>
     <xsl:with-param name="param_node" select="."/>
   </xsl:call-template>
  </xsl:when>
  <!-- Check if the Parameter contains the requested string in the description -->
  <xsl:when test="contains($description_lc,$param)">
   <xsl:call-template name="OutputParam">
     <xsl:with-param name="component_name" select="$component_name"/>
     <xsl:with-param name="param_prefix" select="$param_prefix"/>
     <xsl:with-param name="param_name" select="."/>
   </xsl:call-template>
  </xsl:when>
 </xsl:choose>
 </xsl:if>
</xsl:template>

<!-- Process each component -->
<xsl:template match="component[@name]">
 <xsl:variable name="component_name">
  <xsl:value-of select="@name"/>
 </xsl:variable>
<!-- Get the prefix to be used for the component -->
<xsl:variable name="param_prefix">
  <xsl:call-template name="GetPrefix">
    <xsl:with-param name="node" select="."/>
 </xsl:call-template>
 </xsl:variable>
<!-- For each initialization parameters -->
<xsl:for-each select="config-template/init/param[@name]">
<xsl:call-template name="ProcessParam">
  <xsl:with-param name="component_name" select="$component_name"/>
  <xsl:with-param name="param_prefix" select="$param_prefix"/>
 </xsl:call-template>
</xsl:for-each>
<!-- For each configuration parameters -->
<xsl:for-each select="config-template/config/param[@name]">
<xsl:call-template name="ProcessParam">
  <xsl:with-param name="component_name" select="$component_name"/>
  <xsl:with-param name="param_prefix" select="$param_prefix"/>
 </xsl:call-template>
</xsl:for-each>
</xsl:template> 

<!-- Start the macthing -->
<xsl:template match="/service">
  <xsl:if test="string($PrintUsage)">
     <xsl:call-template name="Usage"/>
  </xsl:if>
  <xsl:choose>
     <xsl:when test="string-length($Param) = 0">
       <xsl:call-template name="Usage"/>
     </xsl:when>
     <xsl:otherwise>
********************************************************************************
*
* Searching for : &quot;<xsl:value-of select="$param"/>&quot;
*
********************************************************************************
       <xsl:apply-templates/>
     </xsl:otherwise>
   </xsl:choose>
</xsl:template>
</xsl:stylesheet>
